//	GamePlayState.cpp - The main gameplay state.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "drawing/ImageLoader.h"
#include "drawing/Drawer.h"
#include "GamePlayState.h"
#include "MiscHelper.h"
#include "UTF8File.h"

using std::wstring;
using std::vector;

//------------------------------------------------------------------------------
GameStateCreator<GamePlayState> GamePlayState::creator;

//------------------------------------------------------------------------------
GamePlayState::GamePlayState(Application& app, SounderPtr& sound):
GameState(app, sound),
intro(true),
plasmaVal(0.0f),
loaded(false),
lineIndex(0.0f),
lineInc(0.0f),
tweenerTest(1.0f),
tweener(tweenerTest, 2.0f, 0.01f),
tweenerTest2(128.0f),
tweener2(tweenerTest2, TwoFloats(256.0f), 0.01f),
sounder(sound)
{
	UTF8File phil(FilePath::getHomeDir().getChild(L"unicodeText.txt"));

	phil.readFile(unicodeText);
}

//------------------------------------------------------------------------------
GamePlayState::~GamePlayState()
{

}

//------------------------------------------------------------------------------
void GamePlayState::update(float delta)
{
	plasmaVal += 0.01f;
	if(plasmaVal > 6.283185f)
		plasmaVal = fmodf(plasmaVal, 6.283185f);

	if(!tweener.getFinished())
		tweener.tick(delta);
	if(!tweener2.getFinished())
		tweener2.tick(delta);
}

//------------------------------------------------------------------------------
void GamePlayState::draw(DrawerPtr& d)
{
	const TwoFloats origin;
	const ThreeFloats black;
	const ThreeFloats white(1.0f);
	const TwoFloats textPos(16.0f, 48.0f);

	/*if(!loaded)
	{
		int x, y, i;
		float tempf;
		const int bufSize = 512;
		uint8_t *plasmaBuffer = new uint8_t[bufSize*bufSize*4];
		uint8_t *plasmaBuffer2 = new uint8_t[bufSize*bufSize*4];

		loaded = true;

		d->useShader(L"PlasmaShader");
		d->registerShaderParam(L"time");
		d->useShader(L"");

		i = 0;
		for(y=0;y<bufSize;++y)
		{
			for(x=0;x<bufSize;++x)
			{
				tempf = sinf(((float)x/128.0f) * 6.283185f);
				tempf += 1.0f;
				tempf *= 0.5f;
				//tempf = fakeExp(tempf);
				tempf *= 255.9f;

				plasmaBuffer[i] = (uint8_t)(tempf);
				plasmaBuffer[i+1] = (uint8_t)(tempf);
				plasmaBuffer[i+2] = (uint8_t)(tempf);
				plasmaBuffer[i+3] = 255;

				tempf = sinf(((float)x/128.0f) * 6.283185f) * 0.5f;
				tempf += cosf(((float)y/128.0f) * 6.283185f) * 0.5f;
				tempf += 1.0f;
				tempf *= 0.5f;
				//tempf = fakeExp(tempf);
				//tempf *= ((tanhf(((float)x/256.0f) * 6.283185f)) + 1.0f) * 0.5f;
				tempf *= 255.9f;

				plasmaBuffer2[i] = (uint8_t)(tempf);
				plasmaBuffer2[i+1] = (uint8_t)(tempf);
				plasmaBuffer2[i+2] = (uint8_t)(tempf);
				plasmaBuffer2[i+3] = 255;

				i += 4;
			}
		}
		d->loadSingleImage(plasmaBuffer, bufSize, bufSize, L"Plasma3");
		d->loadSingleImage(plasmaBuffer2, bufSize, bufSize, L"Plasma4");
	}*/

	//d->startFrameBufferDrawing();

	if(intro)
	{
		d->fillRect(origin, d->getDrawingAreaSize(), black);

		/*d->drawText(L"Our stories are wrong.\nWe have wasted years telling ourselves the wrong fictions.",
					L"font1",
					layouts[0],
					textPos,
					d->getDrawingAreaSize().x,
					TextLayout::Centre,
					1.0f,
					white);*/
		d->drawText(unicodeText,
					L"font1",
					layouts[0],
					textPos,
					d->getDrawingAreaSize().x-32.0f,
					TextLayout::Left,
					1.0f,
					white);

		/*d->setBlendMode(Drawer::Additive);
		d->drawImage(L"Star",
					 TwoFloats(128.0f),
					 TwoFloats(1.0f),
					 ThreeFloats(1.0f, 0.1f, 0.1f));
		d->drawImage(L"StarBlur",
					 TwoFloats(128.0f),
					 TwoFloats(1.0f),
					 ThreeFloats(1.0f, 0.1f, 0.1f));
		d->setBlendMode(Drawer::AlphaBlend);*/
	}
	else
	{
		d->fillRect(origin, d->getDrawingAreaSize(), white);

		d->drawTiledImage(L"GrassTile",
						  origin,
						  d->getDrawingAreaSize(),
						  origin,
						  TwoFloats((1280.0f/512.0f), (720.0f/512.0f)));

		player.draw(d);

		d->drawImage(L"Rock", tweenerTest2, TwoFloats(tweenerTest));

		d->drawImage(L"NonPowerOfTwo", TwoFloats(64.0f), TwoFloats(4.0f));

		/*d->useSecondImage(L"Plasma3");
		d->useShader(L"PlasmaShader");
		d->setShaderParam(L"time", plasmaVal);
		//d->drawImage(L"Plasma4", TwoFloats(-384.0f, -664.0f), TwoFloats(4.0f));
		d->drawImage(L"Plasma4", origin, TwoFloats(1280.0f/512.0f));
		d->useShader(L"");
		d->useSecondImage(L"");*/

		/*d->drawLine(L"", origin, d->getDrawingAreaSize(), ThreeFloats(1.0f, 0.0f, 0.0f), 0.5f);

		TwoFloats temp2f;

		temp2f.x = 640.0f + (sinf(lineIndex) * 120.0f);
		temp2f.y = 360.0f + (cosf(lineIndex) * 120.0f);
		d->drawLine(L"", TwoFloats(640.0f, 360.0f), temp2f);
		if(lineInc != 0.0f)
			lineIndex += lineInc;*/

		//if(plasmaVal < 6.283185f)
		/*{
		plasmaVal += 0.01f;
		if(plasmaVal > 6.283185f)
			plasmaVal = fmodf(plasmaVal, 6.283185f);
		}*/

		{
			unsigned int i;
			vector<TwoFloats> points;
			vector<float> pointsScale;
			vector<ThreeFloats> pointsCol;
			vector<float> pointsAlpha;

			for(i=0;i<64;++i)
			{
				points.push_back(mousePos[i]);
				pointsScale.push_back(16.0f);
				pointsCol.push_back(ThreeFloats(1.0f, 0.0f, 0.0f));
				if(i<62)
					pointsAlpha.push_back((float)(61-i)/61.0f);
			}
			pointsAlpha.push_back(0.0f);
			pointsAlpha.push_back(0.0f);
			d->drawConnectedLine(L"", points, pointsScale, pointsCol, pointsAlpha);
		}
	}

	/*d->endFrameBufferDrawing();

	d->useSecondImage(L"spaceNoise");
	d->useShader(L"PostProc");
	d->drawImage(d->getFrameBufferImage(), origin);
	d->useShader(L"");
	d->useSecondImage(L"");*/
}

//------------------------------------------------------------------------------
void GamePlayState::keyDown(const wstring& action,
							const wstring& keyPressed,
							int keyModifier)
{
	if(action == L"Escape")
		quit();
	else if(intro)
		intro = false;
	else if((action == L"P1Up") || (action == L"P1Left") || (action == L"P1Right") || (action == L"P1Down"))
		player.move(action, true);
	else if(keyPressed == L"a")
		lineInc = -0.01f;
	else if(keyPressed == L"d")
		lineInc = 0.01f;
	else if(keyPressed == L"t")
	{
		if(tweenerTest > 1.5f)
			tweener.reset(1.0f);
		else
			tweener.reset(2.0f);
	}
	else if(keyPressed == L"y")
	{
		if(tweenerTest2.x > 192.0f)
			tweener2.reset(TwoFloats(128.0f));
		else
			tweener2.reset(TwoFloats(256.0f));
	}
}

//------------------------------------------------------------------------------
void GamePlayState::keyUp(const wstring& action,
							const wstring& keyPressed,
							int keyModifier)
{
	if((action == L"P1Up") || (action == L"P1Left") || (action == L"P1Right") || (action == L"P1Down"))
		player.move(action, false);
	else if(keyPressed == L"a")
		lineInc = 0.0f;
	else if(keyPressed == L"d")
		lineInc = 0.0f;
}

//------------------------------------------------------------------------------
void GamePlayState::mouseMove(const TwoFloats& pos)
{
	int i;

	for(i=63;i>0;--i)
		mousePos[i] = mousePos[i-1];
	mousePos[0] = pos;
}
