//	GamePlayState.h - The main gameplay state.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef GAMEPLAYSTATE_H_
#define GAMEPLAYSTATE_H_

#include "Tweener.h"
#include "GameState.h"
#include "drawing/TextLayout.h"

#include "Player.h"

///	The main gameplay state.
class GamePlayState : public GameState
{
  public:
	///	Constructor.
	GamePlayState(Application& app, SounderPtr& sound);
	///	Destructor.
	~GamePlayState();

	///	Called frequently to update the state.
	void update(float delta);
	///	Called to draw the state.
	void draw(DrawerPtr& d);

	///	Called when a key down event is received.
	void keyDown(const std::wstring& action,
				 const std::wstring& keyPressed,
				 int keyModifier);
	///	Called when a key up event is received.
	void keyUp(const std::wstring& action,
			   const std::wstring& keyPressed,
			   int keyModifier);

	///	Used to test connected line drawing.
	void mouseMove(const TwoFloats& pos);

	///	Returns the name of this state.
	const std::wstring getName() const {return L"GamePlayState";};
	///	Used to construct instances of this state.
	static GameStateCreator<GamePlayState> creator;
  private:
	///	Where we store the layouts for our text.
	TextLayout layouts[3];

	///	Whether we're currently displaying the intro text or not.
	bool intro;

	///	The player character.
	Player player;

	///	Some unicode text to display.
	std::wstring unicodeText;

	///	Used to move the plasma.
	float plasmaVal;
	///	Used to setup the plasma texture.
	bool loaded;

	///	Used to test line drawing.
	float lineIndex;
	///	Used to test line drawing.
	float lineInc;

	///	Used to test connected line drawing.
	TwoFloats mousePos[64];

	///	Used to test Tweener classes.
	float tweenerTest;
	///	Used to test Tweener classes.
	BounceTweener<float> tweener;
	///	Used to test Tweener classes.
	TwoFloats tweenerTest2;
	///	Used to test Tweener classes.
	BounceTweener<TwoFloats> tweener2;

	///	Our sounder.
	SounderPtr sounder;
};

#endif
