//	GridGame.h - Main gameplay state for the grid game thing.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef GRIDGAME_H_
#define GRIDGAME_H_

#include "GameState.h"
#include "drawing/TextLayout.h"

#include "PlayerPiece.h"

///	Main gameplay state for the grid game thing.
class GridGame : public GameState
{
  public:
	///	Constructor.
	GridGame(Application *app, Sounder *sound);
	///	Destructor.
	~GridGame();

	///	Draws the current state.
	void draw(DrawerPtr d);

	///	Called when a key down event is received.
	void keyDown(const std::wstring& action,
				 const std::wstring& keyPressed,
				 int keyModifier);
	///	Called when a key up event is received.
	void keyUp(const std::wstring& action,
			   const std::wstring& keyPressed,
			   int keyModifier);

	///	Returns the name of this state.
	const std::wstring getName() const {return L"GridGame";};
	///	Used to construct instances of this state.
	static GameStateCreator<GridGame> creator;
  private:
	///	Returns an RGB value from a hue value.
	ThreeFloats rgbFromHue(float hue);

	///	Where we store the layouts for our text.
	TextLayout layouts[3];

	///	The three colours used to interpolate the background.
	ThreeFloats background[3];
	///	The two colours used to interpolate the player pieces.
	ThreeFloats playerCol[2];
	///	Used to interpolate the background colours.
	float backInterp;

	///	The 3 player pieces.
	PlayerPiece playerPieces[3];
	///	Which player piece is selected.
	int selectedPlayer;

	///	Our sounder.
	Sounder *sounder;
};

#endif
