//	NewLoadingScreen.cpp - Testing a new loading screen animation.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "NewLoadingScreen.h"
#include "drawing/Drawer.h"
#include "MiscHelper.h"
#include "Random.h"

//------------------------------------------------------------------------------
GameStateCreator<NewLoadingScreen> NewLoadingScreen::creator;

//------------------------------------------------------------------------------
NewLoadingScreen::NewLoadingScreen(Application& app, SounderPtr& sound):
GameState(app, sound)
{
	int x, y;

	colours[Background] = ThreeFloats(1.0f);
	colours[PixelBright] = ThreeFloats(1.0f, 0.5f, 0.5f);
	//colours[PixelBright] = ThreeFloats(0.0f);
	colours[PixelDark] = ThreeFloats(0.0f, 0.0f, 1.0f);
	//colours[PixelDark] = ThreeFloats(0.8f);
	colours[EndFade] = ThreeFloats(0.0f);

	for(y=0;y<GridHeight;++y)
	{
		for(x=0;x<GridWidth;++x)
			grid[y][x] = 0.0f;
	}
}

//------------------------------------------------------------------------------
NewLoadingScreen::~NewLoadingScreen()
{

}

//------------------------------------------------------------------------------
void NewLoadingScreen::draw(DrawerPtr& d)
{
	int x, y;
	TwoFloats tempPos;
	TwoFloats cellDist;
	ThreeFloats tempCol;
	const TwoFloats origin;

	cellDist.x = (d->getDrawingAreaSize().x - 0.0f)/(float)GridWidth;
	cellDist.y = (d->getDrawingAreaSize().y - 0.0f)/(float)GridHeight;

	//Fill background.
	d->fillRect(origin, d->getDrawingAreaSize(), colours[Background]);

	//Draw 'pixels'.
	tempPos = 0.0f + (cellDist * 0.5f);
	for(y=0;y<GridHeight;++y)
	{
		tempPos.x = 0.0f + (cellDist.x * 0.5f);
		for(x=0;x<GridWidth;++x)
		{
			tempCol = (colours[PixelBright] * grid[y][x]) + (colours[PixelDark] * (1.0f-grid[y][x]));

			d->fillRect(tempPos - (cellDist * grid[y][x] * 0.5f),
						cellDist * grid[y][x],
						tempCol,
						grid[y][x]);

			tempPos.x += cellDist.x;

			if(grid[y][x] > 0.0f)
			{
				grid[y][x] -= 0.02f;
				if(grid[y][x] < 0.0f)
					grid[y][x] = 0.0f;
			}
			/*if(grid[y][x] > 0.0f)
			{
				grid[y][x] += 0.02f;
				if(grid[y][x] > 1.0f)
					grid[y][x] = 1.0f;
			}*/
		}
		tempPos.y += cellDist.y;
	}
}

//------------------------------------------------------------------------------
void NewLoadingScreen::keyDown(const std::wstring& action,
							   const std::wstring& keyPressed,
							   int keyModifier)
{
	if(action == L"Escape")
		quit();
}

//------------------------------------------------------------------------------
void NewLoadingScreen::mouseMove(const TwoFloats& pos)
{
	mousePos = pos;

	//Random fill.
	/*int x, y;
	bool breakNow;
	int numDesired;
	int numFilled = 0;
	struct TempPoint
	{
		int x;
		int y;
		TempPoint(int xVal, int yVal):
		x(xVal),
		y(yVal)
		{
		};
	};
	std::vector<TempPoint> remaining;
	float fillAmount = mousePos.x/(getDrawingAreaSize().x * 0.99f);

	numDesired = (int)(fillAmount * (float)(GridHeight*GridWidth));

	for(y=0;y<GridHeight;++y)
	{
		for(x=0;x<GridWidth;++x)
		{
			if(grid[y][x] > 0.0f)
				++numFilled;
			else
				remaining.push_back(TempPoint(x, y));
		}
	}
	numDesired -= numFilled;

	while((numDesired > 0) && (remaining.size() > 0))
	{
		x = Random::getGlobal().getRandomInt(remaining.size());

		grid[remaining[x].y][remaining[x].x] = 0.02f;
		remaining.erase(remaining.begin()+x);
		--numDesired;
	}*/

	//Sin wave.
	/*float sinIndex;
	TwoFloats tempf;

	sinIndex = mousePos.x/getDrawingAreaSize().x;
	tempf.x = (mousePos.x/getDrawingAreaSize().x) * (float)GridWidth;
	tempf.y = ((float)GridHeight*0.5f);
	tempf.y += sinf(sinIndex * 2.0f * NIALL_PI * 4.0f) * ((float)GridHeight*0.25f);
	grid[(int)tempf.y][(int)tempf.x] = 1.0f;*/

	//Spiral.
	TwoFloats tempf;
	float spiralIndex;

	spiralIndex = mousePos.x/getDrawingAreaSize().x;
	tempf.x = ((float)GridWidth * 0.5f);
	tempf.x += sinf(spiralIndex * 2.0f * NIALL_PI * 4.0f) * spiralIndex * ((float)GridHeight * 0.5f);
	tempf.y = ((float)GridHeight * 0.5f);
	tempf.y += cosf(spiralIndex * 2.0f * NIALL_PI * 4.0f) * spiralIndex * ((float)GridHeight * 0.5f);
	grid[(int)tempf.y][(int)tempf.x] = 1.0f;
	if(tempf.y >= 1.0f)
	{
		grid[(int)tempf.y-1][(int)tempf.x] += 0.5f;
		if(grid[(int)tempf.y-1][(int)tempf.x] > 1.0f)
			grid[(int)tempf.y-1][(int)tempf.x] = 1.0f;
	}
	if(tempf.y <= (float)(GridHeight-2))
	{
		grid[(int)tempf.y+1][(int)tempf.x] += 0.5f;
		if(grid[(int)tempf.y+1][(int)tempf.x] > 1.0f)
			grid[(int)tempf.y+1][(int)tempf.x] = 1.0f;
	}
	if(tempf.x >= 1.0f)
	{
		grid[(int)tempf.y][(int)tempf.x-1] += 0.5f;
		if(grid[(int)tempf.y][(int)tempf.x-1] > 1.0f)
			grid[(int)tempf.y][(int)tempf.x-1] = 1.0f;
	}
	if(tempf.x <= (float)(GridWidth-2))
	{
		grid[(int)tempf.y][(int)tempf.x+1] += 0.5f;
		if(grid[(int)tempf.y][(int)tempf.x+1] > 1.0f)
			grid[(int)tempf.y][(int)tempf.x+1] = 1.0f;
	}

	//Mouse pos = pixel.
	/*int x, y;

	x = (int)(mousePos.x/(getDrawingAreaSize().x/(float)GridWidth));
	y = (int)(mousePos.y/(getDrawingAreaSize().y/(float)GridHeight));
	grid[y][x] = 1.0f;*/
}
