//	NewLoadingScreen.h - Testing a new loading screen animation.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef NEWLOADINGSCREEN_H_
#define NEWLOADINGSCREEN_H_

#include "ThreeFloats.h"
#include "GameState.h"

///	Testing a new loading screen animation.
class NewLoadingScreen : public GameState
{
  public:
	///	Constructor.
	NewLoadingScreen(Application& app, SounderPtr& sound);
	///	Destructor.
	~NewLoadingScreen();

	///	Draws the screen.
	void draw(DrawerPtr& d);

	///	Used to quit.
	void keyDown(const std::wstring& action,
				 const std::wstring& keyPressed,
				 int keyModifier);

	///	Used to set the loading amount.
	void mouseMove(const TwoFloats& pos);

	///	Returns the name of this state.
	const std::wstring getName() const {return L"NewLoadingScreen";};
	///	Used to construct instances of this state.
	static GameStateCreator<NewLoadingScreen> creator;
  private:
	///	IDs of the various colours we use.
	enum
	{
		Background = 0,
		PixelBright,
		PixelDark,
		EndFade,

		NumColours
	};
	///	The size of the 'pixel' grid we use.
	enum
	{
		GridWidth = 16,
		GridHeight = 9
	};

	///	The current mouse position.
	TwoFloats mousePos;

	///	The various colours we use.
	ThreeFloats colours[NumColours];

	///	Our grid of 'pixels'.
	float grid[GridHeight][GridWidth];
};

#endif
