//	PhaseDriftState.cpp - The main gameplay state.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "PhaseDriftState.h"
#include "drawing/Drawer.h"
#include "MiscHelper.h"
#include "UTF8File.h"

#include <cmath>

using std::wstring;

//------------------------------------------------------------------------------
GameStateCreator<PhaseDriftState> PhaseDriftState::creator;

//------------------------------------------------------------------------------
PhaseDriftState::PhaseDriftState(Application& app, SounderPtr& sound):
GameState(app, sound),
rot(0.0f),
rotSpeed(0.002f),
mousePos(0.5f, 0.5f),
fadeIn(1.0f),
sounder(sound)
{
	
}

//------------------------------------------------------------------------------
PhaseDriftState::~PhaseDriftState()
{

}

//------------------------------------------------------------------------------
void PhaseDriftState::draw(DrawerPtr& d)
{
	float index;
	float radius;
	TwoFloats pos;
	TwoFloats scale(0.33f);
	ThreeFloats col1(0.1f, 0.1f, 1.0f);
	ThreeFloats col2(1.0f, 0.1f, 0.1f);
	const wstring tempstr(L"point");
	const TwoFloats centre = d->getDrawingAreaSize()*0.5f;

	static float dist = 0.0f;
	//float dist2 = sinf(dist * 6.283185f) * 0.001f;
	float scaleExtra;
	float rad = 16.0f + (mousePos.x * 40.0f);

	if(drawSize == 0.0f)
		drawSize = d->getDrawingAreaSize();

	for(radius=0.0f;radius<512.0f;radius+=rad)
	{
		scaleExtra = (radius/512.0f) * 4.0f * mousePos.y;
		scaleExtra += (1.0f-(radius/512.0f)) * 2.0f * (1.0f-mousePos.y);

		for(index=0.0f;index<1.0f;index+=(1.0f/32.0f))
		{
			pos.x = centre.x + (sinf((index+(rot*(radius/512.0f))) * 6.283185f) * radius);
			pos.y = centre.y + (cosf((index+(rot*(radius/512.0f))) * 6.283185f) * radius);

			d->drawImage(tempstr,
						 pos - (32.0f * scale.x * scaleExtra),
						 scale * scaleExtra,
						 col1,
						 0.75f);

			if((index == 0.0f) && (radius == 0.0f))
				break;
		}
	}

	for(radius=0.0f;radius<512.0f;radius+=rad)
	{
		scaleExtra = (radius/512.0f) * 4.0f * mousePos.y;
		scaleExtra += (1.0f-(radius/512.0f)) * 2.0f * (1.0f-mousePos.y);

		for(index=0.0f;index<1.0f;index+=(1.0f/32.0f))
		{
			pos.x = centre.x + (sinf((index+dist*(rot*(radius/512.0f))) * 6.283185f) * radius);
			pos.y = centre.y + (cosf((index+dist*(rot*(radius/512.0f))) * 6.283185f) * radius);

			d->drawImage(tempstr,
						 pos - (32.0f * scale.x * scaleExtra),
						 scale * scaleExtra,
						 col2,
						 0.75f);

			if((index == 0.0f) && (radius == 0.0f))
				break;
		}
	}

	if(fadeIn > 0.0f)
	{
		d->fillRect(0.0f, d->getDrawingAreaSize(), 0.0f, fadeIn);

		fadeIn -= 0.02f;
	}

	//rotSpeed = 0.002f * ((mousePos.x-0.5f)*2.0f);

	rot += rotSpeed;
	if(rot > 2.0f)
		rot -= 2.0f;
	else if(rot < 0.0f)
		rot += 2.0f;

	dist += 0.0005f;
	if(dist > 1.0f)
		dist -= 1.0f;
}

//------------------------------------------------------------------------------
void PhaseDriftState::keyDown(const wstring& action,
							const wstring& keyPressed,
							int keyModifier)
{
	if(action == L"Escape")
		quit();
}

//------------------------------------------------------------------------------
void PhaseDriftState::keyUp(const wstring& action,
							const wstring& keyPressed,
							int keyModifier)
{
	
}

//------------------------------------------------------------------------------
void PhaseDriftState::mouseMove(const TwoFloats& pos)
{
	mousePos = pos/drawSize;
}
