//	PhaseDriftState.h - The main gameplay state.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef PHASEDRIFTSTATE_H_
#define PHASEDRIFTSTATE_H_

#include "GameState.h"

///	The main gameplay state.
class PhaseDriftState : public GameState
{
  public:
	///	Constructor.
	PhaseDriftState(Application& app, SounderPtr& sound);
	///	Destructor.
	~PhaseDriftState();

	///	Draws the current state.
	void draw(DrawerPtr& d);

	///	Called when a key down event is received.
	void keyDown(const std::wstring& action,
				 const std::wstring& keyPressed,
				 int keyModifier);
	///	Called when a key up event is received.
	void keyUp(const std::wstring& action,
			   const std::wstring& keyPressed,
			   int keyModifier);

	///	Called when a mouse move event is received.
	void mouseMove(const TwoFloats& pos);

	///	Returns the name of this state.
	const std::wstring getName() const {return L"PhaseDriftState";};
	///	Used to construct instances of this state.
	static GameStateCreator<PhaseDriftState> creator;
  private:
	///	Rotates the points.
	float rot;
	///	The speed of the rotation.
	float rotSpeed;

	///	Mouse position (0->1).
	TwoFloats mousePos;
	///	Drawing area size.
	TwoFloats drawSize;

	///	Used to fade in at the start.
	float fadeIn;

	///	Our sounder.
	SounderPtr sounder;
};

#endif
