//	Player.cpp - Simple class representing the player.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "Player.h"
#include "MiscHelper.h"

using std::wstring;

//------------------------------------------------------------------------------
Player::Player():
position(640.0f, 360.0f),
frame(0),
animCount(4)
{
	keys[0] = false;
	keys[1] = false;
	keys[2] = false;
	keys[3] = false;

	animNames[0] = L"hoodedGuy0";
	animNames[1] = L"hoodedGuy1";
	animNames[2] = L"hoodedGuy2";
	animNames[3] = L"hoodedGuy1";
	animNames[4] = L"hoodedGuy0";
	animNames[5] = L"hoodedGuy5";
	animNames[6] = L"hoodedGuy6";
	animNames[7] = L"hoodedGuy5";
	animNames[8] = L"hoodedGuyBack0";
	animNames[9] = L"hoodedGuyBack1";
	animNames[10] = L"hoodedGuyBack2";
	animNames[11] = L"hoodedGuyBack1";
	animNames[12] = L"hoodedGuyBack0";
	animNames[13] = L"hoodedGuyBack5";
	animNames[14] = L"hoodedGuyBack6";
	animNames[15] = L"hoodedGuyBack5";
}

//------------------------------------------------------------------------------
Player::~Player()
{

}

//------------------------------------------------------------------------------
void Player::draw(DrawerPtr d)
{
	int dirX = 0;
	int dirY = 0;
	int frameOffset = 0;
	TwoFloats scale(1.0f, 1.0f);

	if(keys[0] && !keys[3])
	{
		position.y -= 2.0f;
		dirY = -1;
	}
	else if(!keys[0] && keys[3])
	{
		position.y += 2.0f;
		dirY = 1;
	}
	if(keys[1] && !keys[2])
	{
		position.x -= 2.0f;
		dirX = -1;
	}
	else if(!keys[1] && keys[2])
	{
		position.x += 2.0f;
		dirX = 1;
	}

	if(dirX < 0)
		scale.x = -1.0f;
	if(dirY < 0)
		frameOffset = 8;
	if(!dirX && !dirY)
	{
		frame = 0;
		animCount = 4;
	}
	else
	{
		--animCount;
		if(!animCount)
		{
			++frame;
			frame %= 8;
			animCount = 4;
		}
	}

	d->drawImage(animNames[frame+frameOffset], position-(scale * 32.0f), scale);
}

//------------------------------------------------------------------------------
void Player::move(const wstring& action, bool keyVal)
{
	if(action == L"P1Up")
		keys[0] = keyVal;
	else if(action == L"P1Left")
		keys[1] = keyVal;
	else if(action == L"P1Right")
		keys[2] = keyVal;
	else if(action == L"P1Down")
		keys[3] = keyVal;
}
