//	Player.h - Simple class representing the player.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef PLAYER_H_
#define PLAYER_H_

#include "drawing/Drawer.h"

///	Simple class representing the player.
class Player
{
  public:
	///	Constructor.
	Player();
	///	Destructor.
	~Player();

	///	Draws the player.
	void draw(DrawerPtr d);

	///	Instructs the player to move.
	void move(const std::wstring& action, bool keyVal);
  private:
	///	The player's position.
	TwoFloats position;

	///	Whether the 4 movement keys are being pressed.
	bool keys[4];

	///	The image names (for convenience).
	std::wstring animNames[16];
	///	Which animation frame we're on.
	int frame;
	///	So we don't update the frame for every rendered frame.
	int animCount;
};

#endif
