//	PlayerPiece.cpp - Class representing a player piece in the game.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "PlayerPiece.h"
#include "drawing/Drawer.h"

//------------------------------------------------------------------------------
PlayerPiece::PlayerPiece():
xPos(0),
yPos(0)
{

}

//------------------------------------------------------------------------------
PlayerPiece::~PlayerPiece()
{

}

//------------------------------------------------------------------------------
void PlayerPiece::setPosition(int x, int y)
{
	xPos = x;
	yPos = y;
}

//------------------------------------------------------------------------------
void PlayerPiece::setLetter(const std::wstring& val)
{
	letter = val;
}

//------------------------------------------------------------------------------
void PlayerPiece::draw(DrawerPtr d, const ThreeFloats& col, bool selected)
{
	const TwoFloats noScale(1.0f);
	ThreeFloats selectedCol;

	if(selected)
	{
		selectedCol.x = (1.0f-col.x) * 1.5f;
		selectedCol.y = (1.0f-col.y) * 1.5f;
		selectedCol.z = (1.0f-col.z) * 1.5f;
	}
	else
		selectedCol = 1.0f;

	d->drawImage(L"CircleBack",
				 TwoFloats((xPos*80)+7, (yPos*80)+7),
				 noScale,
				 selectedCol);
	d->drawImage(L"CircleFront",
				 TwoFloats((xPos*80)+22, (yPos*80)+22),
				 noScale,
				 col);
	d->drawText(letter,
				L"font1",
				letterLayout,
				TwoFloats((xPos*80), (yPos*80)+46),
				80.0f,
				TextLayout::Centre,
				1.0f,
				selectedCol);
}

//------------------------------------------------------------------------------
void PlayerPiece::move(int dir)
{
	switch(dir)
	{
		case 0: //Up.
			if(yPos > 0)
				--yPos;
			break;
		case 1: //Left.
			if(xPos > 0)
				--xPos;
			break;
		case 2: //Right.
			if(xPos < 15)
				++xPos;
			break;
		case 3: //Down.
			if(yPos < 8)
				++yPos;
			break;
	}
}
