//	PlayerPiece.h - Class representing a player piece in the game.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef PLAYERPIECE_H_
#define PLAYERPIECE_H_

#include "drawing/TextLayout.h"
#include "ThreeFloats.h"
#include "c0xHeaders.h"

#include <string>

class Drawer;

typedef StdSharedPtr<Drawer>::type DrawerPtr;

///	Class representing a player piece in the game.
class PlayerPiece
{
  public:
	///	Constructor.
	PlayerPiece();
	///	Destructor.
	~PlayerPiece();

	///	Sets the piece's position.
	void setPosition(int x, int y);
	///	Sets the piece's letter.
	void setLetter(const std::wstring& val);

	///	Draws the piece.
	void draw(DrawerPtr d, const ThreeFloats& col, bool selected);

	///	Moves the piece in one of 4 directions (0:up, 1:left, 2:right, 3:down).
	void move(int dir);

	///	Returns the piece's position.
	int getX() const {return xPos;};
	///	Returns the piece's position.
	int getY() const {return yPos;};
  private:
	///	The piece's position.
	int xPos;
	///	The piece's position.
	int yPos;
	///	The piece's letter.
	std::wstring letter;

	///	Cached TextLayout for the letter.
	TextLayout letterLayout;
};

#endif
